## Simple alias to mimic the OpenBUGS script command 

"modelSetWD" <- function(dir) setwd(dir)
